@@ -35,9 +35,9 @@
 
 /* Show the user's guide for gtranslator */
 void
-gtr_show_help (GtrWindow *window)
+gtr_show_help (GtkWindow *window)
 {
-  gtr_utils_help_display (GTK_WINDOW (window), "gtranslator", "");
+  gtr_utils_help_display (GTK_WINDOW (window));
 }
 
 /* Creates and shows the about box for gtranslator */
