@@ -34,6 +34,8 @@
 #include "gtr-utils.h"
 #include "gtr-window.h"
 #include "gtr-preferences-dialog.h"
+#include "gtr-search-bar.h"
+#include "gtr-tab.h"
 
 #include <glib.h>
 #include <glib-object.h>
@@ -183,12 +185,6 @@ gtr_application_init (GtrApplication *application)
   if (!g_file_test (profiles_file, G_FILE_TEST_EXISTS))
     priv->first_run = TRUE;
   g_free (profiles_file);
-
-  /* Custom css */
-  priv->provider = gtk_css_provider_new ();
-  gtk_css_provider_load_from_resource (priv->provider, "/org/gnome/translator/styles.css");
-
-  load_accels ();
 }
 
 static void
@@ -227,6 +223,17 @@ new_window_activated (GSimpleAction *action,
   gtk_application_add_window (GTK_APPLICATION (app), GTK_WINDOW (window));
 }
 
+static void
+find_toggle_activated (GSimpleAction *action,
+                       GVariant      *parameter,
+                       gpointer       user_data)
+{
+  GtrApplication *app = GTR_APPLICATION (user_data);
+  GtrApplicationPrivate *priv = gtr_application_get_instance_private (app);
+
+  gtr_window_toggle_search_bar (priv->active_window);
+}
+
 static void
 find_activated (GSimpleAction *action,
                 GVariant      *parameter,
@@ -235,7 +242,49 @@ find_activated (GSimpleAction *action,
   GtrApplication *app = GTR_APPLICATION (user_data);
   GtrApplicationPrivate *priv = gtr_application_get_instance_private (app);
 
-  _gtr_actions_search_find (NULL, priv->active_window);
+  GtrTab *active_tab = gtr_window_get_active_tab (priv->active_window);
+  g_return_if_fail (active_tab != NULL);
+  gtr_window_show_search_bar (priv->active_window, TRUE);
+  gtr_tab_find_set_replace (active_tab, FALSE);
+}
+
+static void
+find_next_activated (GSimpleAction *action,
+                     GVariant      *parameter,
+                     gpointer       user_data)
+{
+  GtrApplication *app = GTR_APPLICATION (user_data);
+  GtrApplicationPrivate *priv = gtr_application_get_instance_private (app);
+
+  GtrTab *active_tab = gtr_window_get_active_tab (priv->active_window);
+  g_return_if_fail (active_tab != NULL);
+  gtr_window_show_search_bar (priv->active_window, TRUE);
+  gtr_tab_find_next (active_tab);
+}
+
+static void
+find_prev_activated (GSimpleAction *action,
+                     GVariant      *parameter,
+                     gpointer       user_data)
+{
+  GtrApplication *app = GTR_APPLICATION (user_data);
+  GtrApplicationPrivate *priv = gtr_application_get_instance_private (app);
+
+  GtrTab *active_tab = gtr_window_get_active_tab (priv->active_window);
+  g_return_if_fail (active_tab != NULL);
+  gtr_window_show_search_bar (priv->active_window, TRUE);
+  gtr_tab_find_prev (active_tab);
+}
+
+static void
+find_unactivated (GSimpleAction *action,
+                GVariant      *parameter,
+                gpointer       user_data)
+{
+  GtrApplication *app = GTR_APPLICATION (user_data);
+
+  GtrApplicationPrivate *priv = gtr_application_get_instance_private (app);
+  gtr_window_show_search_bar (priv->active_window, FALSE);
 }
 
 static void
@@ -246,7 +295,9 @@ find_and_replace_activated (GSimpleAction *action,
   GtrApplication *app = GTR_APPLICATION (user_data);
   GtrApplicationPrivate *priv = gtr_application_get_instance_private (app);
 
-  _gtr_actions_search_replace (NULL, priv->active_window);
+  GtrTab *active_tab = gtr_window_get_active_tab (priv->active_window);
+  gtr_window_show_search_bar (priv->active_window, TRUE);
+  gtr_tab_find_set_replace (active_tab, TRUE);
 }
 
 static void
@@ -321,7 +372,7 @@ help_activated (GSimpleAction *action,
 {
   GtrApplication *app = GTR_APPLICATION (user_data);
   GtrApplicationPrivate *priv = gtr_application_get_instance_private (app);
-  gtr_show_help (priv->active_window);
+  gtr_show_help (GTK_WINDOW (priv->active_window));
 }
 
 static void
@@ -384,6 +435,38 @@ open_activated (GSimpleAction *action,
   gtr_open_file_dialog (NULL, priv->active_window);
 }
 
+static void
+dl_activated (GSimpleAction *action,
+              GVariant      *parameter,
+              gpointer       user_data)
+{
+  GtrApplication *app = GTR_APPLICATION (user_data);
+  GtrApplicationPrivate *priv = gtr_application_get_instance_private (app);
+
+  GtrTab *active_tab = gtr_window_get_active_tab (priv->active_window);
+  GtrPoState state = gtr_po_get_state (gtr_tab_get_po (active_tab));
+
+  if (state == GTR_PO_STATE_MODIFIED)
+    {
+      GtkWidget *dialog;
+      gint res;
+
+      dialog = gtk_message_dialog_new (GTK_WINDOW (priv->active_window),
+            GTK_DIALOG_DESTROY_WITH_PARENT,
+            GTK_MESSAGE_QUESTION,
+            GTK_BUTTONS_YES_NO,
+            _("Do you want to save the changes?"));
+      gtk_window_set_title (GTK_WINDOW (dialog), _("Warning"));
+      res = gtk_dialog_run (GTK_DIALOG (dialog));
+      gtk_widget_destroy (dialog);
+
+      if (res == GTK_RESPONSE_YES)
+        gtr_save_current_file_dialog (NULL, priv->active_window);
+    }
+
+  gtr_window_show_dlteams (priv->active_window);
+}
+
 static void
 undo_activated (GSimpleAction *action,
                 GVariant      *parameter,
@@ -498,12 +581,15 @@ sort_by_activated (GSimpleAction *action,
   tab = gtr_window_get_active_tab (w);
   g_return_if_fail (tab != NULL);
   gtr_tab_sort_by (tab, (GtrMessageTableSortBy)sortby);
+  gtr_window_hide_sort_menu (w);
 }
 
 static GActionEntry app_entries[] = {
   { "save", save_activated, NULL, NULL, NULL },
   { "saveas", saveas_activated, NULL, NULL, NULL },
+
   { "open", open_activated, NULL, NULL, NULL },
+  { "dl", dl_activated, NULL, NULL, NULL },
 
   { "undo", undo_activated, NULL, NULL, NULL },
   { "redo", redo_activated, NULL, NULL, NULL },
@@ -538,7 +624,11 @@ static GActionEntry app_entries[] = {
 
   { "copy_text", copy_text_activated, NULL, NULL, NULL },
   { "find_and_replace", find_and_replace_activated, NULL, NULL, NULL },
+  { "findtoggle", find_toggle_activated, NULL, NULL, NULL },
   { "find", find_activated, NULL, NULL, NULL },
+  { "find-off", find_unactivated, NULL, NULL, NULL},
+  { "find-next", find_next_activated, NULL, NULL, NULL },
+  { "find-prev", find_prev_activated, NULL, NULL, NULL },
   { "new_window", new_window_activated, NULL, NULL, NULL },
   { "preferences", preferences_activated, NULL, NULL, NULL },
   { "edit_header", edit_header_activated, NULL, NULL, NULL },
@@ -567,6 +657,13 @@ gtr_application_startup (GApplication *application)
   g_set_application_name (_("Translation Editor"));
   gtk_window_set_default_icon_name (PACKAGE_APPID);
 
+
+  /* Custom css */
+  priv->provider = gtk_css_provider_new ();
+  gtk_css_provider_load_from_resource (priv->provider, "/org/gnome/translator/styles.css");
+
+  load_accels ();
+
   /* We set the default icon dir */
   gtk_icon_theme_append_search_path (gtk_icon_theme_get_default (),
                                      gtr_dirs_get_gtr_pixmaps_dir ());
@@ -576,9 +673,11 @@ gtr_application_startup (GApplication *application)
 
   // keybindings
   set_kb (application, "app.open", "<Ctrl>o");
+  set_kb (application, "app.dl", "<Ctrl>d");
   set_kb (application, "app.save", "<Ctrl>s");
   set_kb (application, "app.saveas", "<Ctrl><Shift>s");
   set_kb (application, "app.preferences", "<Ctrl>p");
+  set_kb (application, "app.quit", "<Primary>q");
 
   set_kb (application, "app.undo", "<Ctrl>z");
   set_kb (application, "app.redo", "<Ctrl><Shift>z");
@@ -590,7 +689,10 @@ gtr_application_startup (GApplication *application)
 
   set_kb (application, "app.fuzzy", "<Ctrl>u");
   set_kb (application, "app.find", "<Ctrl>f");
+  set_kb (application, "app.find-off", "Escape");
   set_kb (application, "app.find_and_replace", "<Ctrl>h");
+  set_kb (application, "app.find-next", "<Ctrl>g");
+  set_kb (application, "app.find-prev", "<Ctrl><Shift>g");
 
   set_kb (application, "app.copy_text", "<Ctrl>space");
 
