@@ -93,6 +93,8 @@ typedef struct
   GtrProfileManager *prof_manager;
   GtkWidget *profile_combo;
 
+  gboolean search_bar_shown;
+
   guint dispose_has_run : 1;
 } GtrWindowPrivate;
 
@@ -700,6 +702,7 @@ gtr_window_init (GtrWindow *window)
   GtkTargetList *tl;
   GtrWindowPrivate *priv = gtr_window_get_instance_private(window);
 
+  priv->search_bar_shown = FALSE;
   priv->state_settings = g_settings_new ("org.gnome.gtranslator.state.window");
 
   gtk_widget_init_template (GTK_WIDGET (window));
@@ -802,14 +805,17 @@ gtr_window_init (GtrWindow *window)
 }
 
 static void
-save_panes_state (GtrWindow * window)
+save_window_state (GtrWindow * window)
 {
   GtrWindowPrivate *priv = gtr_window_get_instance_private(window);
 
-  g_settings_set (priv->state_settings, GTR_SETTINGS_WINDOW_SIZE, "(ii)",
-                  priv->width, priv->height);
-  g_settings_set_int (priv->state_settings, GTR_SETTINGS_WINDOW_STATE,
-                      priv->window_state);
+  if ((priv->window_state &
+	 (GDK_WINDOW_STATE_MAXIMIZED | GDK_WINDOW_STATE_FULLSCREEN)) == 0)
+    {
+      gtk_window_get_size (GTK_WINDOW (window), &priv->width, &priv->height);
+      g_settings_set (priv->state_settings, GTR_SETTINGS_WINDOW_SIZE,
+				"(ii)", priv->width, priv->height);
+    }
 }
 
 static void
@@ -820,8 +826,7 @@ gtr_window_dispose (GObject * object)
 
   if (!priv->dispose_has_run)
     {
-      save_panes_state (window);
-
+      save_window_state (window);
       priv->dispose_has_run = TRUE;
     }
 
@@ -1295,3 +1300,33 @@ gtr_window_tm_keybind (GtrWindow *window,
 
   g_list_free_full (tm_list, free_match);
 }
+
+void
+gtr_window_hide_sort_menu (GtrWindow *window)
+{
+  GtrWindowPrivate *priv = gtr_window_get_instance_private (window);
+
+  gtr_notebook_hide_sort_menu (GTR_NOTEBOOK (priv->notebook));
+}
+
+void
+gtr_window_show_search_bar (GtrWindow *window,
+                            gboolean show)
+{
+  GtrWindowPrivate *priv = gtr_window_get_instance_private (window);
+  GtrNotebook *notebook = GTR_NOTEBOOK (priv->notebook);
+  GtrTab *tab = gtr_window_get_active_tab (window);
+
+  gtr_tab_show_hide_search_bar (tab, show);
+  gtr_notebook_enable_find_button(notebook, show);
+
+  priv->search_bar_shown = show;
+}
+
+void
+gtr_window_toggle_search_bar (GtrWindow *window)
+{
+  GtrWindowPrivate *priv = gtr_window_get_instance_private (window);
+
+  gtr_window_show_search_bar(window, !priv->search_bar_shown);
+}
